@@ -32,9 +32,11 @@ namespace java {
                 initializeClass();
             }
             Long(jlong);
+
+            jlong longValue() const;
         };
 
-        extern PyTypeObject Long$$Type;
+        extern PyTypeObject PY_TYPE(Long);
 
         class t_Long {
         public:
